## Installation

```
pip install apit-lk==0.1.2
```

## Usage
Import

```
from apit.calc import calculate_apit
calculate_apit(gross_income)
```

## Roadmap

- [x] Add Monthly Tax Deductions from Regular Profits from Employment APIT calculation
- [ ] Add Tax breakdown
- [ ] Add other calculation methods with breakdown ( ex: Lump-Sum-Payments,Tax-on-Tax Rates,Bonus..etc)


## Contact

Dinuth Perera - +94776793824 - pm@dinuth.me


## Acknowledgments

Find from below offical Advance Personal Income Tax Tables​​​ & Rules.


* [Sri Lanka IRD - Advance Personal Income Tax Tables​​​ ](http://www.ird.gov.lk/en/publications/sitepages/apit_tax_tables.aspx?menuid=1502)





